@@ -10,6 +10,15 @@ class OrganizationCharacteristics(str, Enum):
     SMALL_TOWN = 'small_town'
     MID_SIZE_CITY = 'mid_size_city'
     LARGE_CITY = 'large_city'
+    INTERNATIONAL = 'international'
+    WEST_COAST = 'west coast'
+    FAMILY_CLOSE = 'family close'
+    REMOTE = 'remote'
+    MULTIPLE_LOCATIONS = 'multiple locations'
+    SPANISH_SPEAKING = 'spanish speaking'
+    FRENCH_SPEAKING = 'french speaking'
+    NOVA = 'northern virginia'
+    SUBURBAN = 'suburban'
 
 
 @dataclass
@@ -23,6 +32,7 @@ class Organization(HasLogo):
     logo_fa_icon_class_str: Optional[str] = None
     address_lines: Optional[Sequence[str]] = None
     city: Optional[str] = None
+    country: Optional[str] = None
     characteristics: Sequence[OrganizationCharacteristics] = tuple()
 
     def __post_init__(self):
