@@ -32,3 +32,7 @@ TEMPLATES_PATH = plbuilder_path('templates')
 templates_path_func = path_func(TEMPLATES_PATH)
 APPLICATIONS_OUT_PATH = 'Applications'
 applications_out_path = path_func(APPLICATIONS_OUT_PATH)
+SPECIFIC_APPLICATIONS_OUT_PATH = '/home/nick/Dropbox/Applications/Job Hunt 2020-2021/Specific Applications/'
+specific_applications_out_path = path_func(SPECIFIC_APPLICATIONS_OUT_PATH)
+PRIVATE_ASSETS_PATH = str(pathlib.Path(__file__).parent.parent.parent / 'Private Assets')
+private_assets_path = path_func(PRIVATE_ASSETS_PATH)
