@@ -2113,5 +2113,46 @@ great location for us.
             },
             by_email=True,
         ),
-
+        CoverLetter(
+            univs.NATIONAL_TAIWAN_TARGET,
+            CoverLetterDesireSection(univs.NATIONAL_TAIWAN_TARGET, ApplicationFocus.ACADEMIC).to_pyexlatex(),
+            included_components=[
+                ApplicationComponents.CV,
+                ApplicationComponents.JOB_MARKET_PAPER,
+                ApplicationComponents.GOVERNMENT_INTERVENTION_PAPER,
+                ApplicationComponents.OPIN_PAPER,
+                ApplicationComponents.RESEARCH_COVER,
+            ],
+            focus=ApplicationFocus.ACADEMIC,
+            combine_files={
+                'Nick DeRobertis Selected Research Work': [
+                    ApplicationComponents.RESEARCH_COVER,
+                    ApplicationComponents.JOB_MARKET_PAPER,
+                    ApplicationComponents.GOVERNMENT_INTERVENTION_PAPER,
+                    ApplicationComponents.OPIN_PAPER,
+                ],
+                'Nick DeRobertis CV and Cover': [
+                    ApplicationComponents.COVER_LETTER,
+                    ApplicationComponents.CV,
+                ]
+            },
+            included_references=[AUTHORS[ANDY], AUTHORS[NIMAL]],
+            by_email=True,
+            add_organization_name_to_address=False,
+        ),
+        CoverLetter(
+            orgs.BEA_USAJOBS_TARGET,
+            CoverLetterDesireSection(
+                orgs.BEA_USAJOBS_TARGET, ApplicationFocus.GOVERNMENT,
+                specific_focus=SpecificApplicationFocus.OTHER_FINANCIAL_REGULATOR
+            ).to_pyexlatex(),
+            included_components=[
+                ApplicationComponents.CV,
+                ApplicationComponents.JOB_MARKET_PAPER,
+            ],
+            focus=ApplicationFocus.GOVERNMENT,
+            font_scale=0.95,
+            line_spacing=0.8,
+            cv_modifier_func=orgs.get_bea_usajobs_cv_model,
+        ),
     ]
