@@ -30,6 +30,7 @@ def get_professional_jobs(
             datetime.datetime(2013, 8, 15),
             company_short_name='EVB',
             short_job_title='Analyst',
+            hours_per_week=30,
         ),
         EmploymentModel(
             JobIDs.CNC_MP.value,
@@ -47,6 +48,7 @@ def get_professional_jobs(
             datetime.datetime(2014, 8, 15),
             company_short_name='CNC',
             short_job_title='MP',
+            hours_per_week=5,
         ),
         EmploymentModel(
             JobIDs.FRB_INTERN.value,
@@ -62,6 +64,7 @@ def get_professional_jobs(
             datetime.datetime(2011, 8, 15),
             company_short_name='FRBG',
             short_job_title='Intern',
+            hours_per_week=40,
         ),
         EmploymentModel(
             JobIDs.PARLIAMENT_TUTOR.value,
@@ -78,6 +81,7 @@ def get_professional_jobs(
             end_date=None,
             company_short_name='PT',
             short_job_title='Tutor',
+            hours_per_week=3,
         )
     ]
     if include_private:
@@ -122,6 +126,7 @@ def get_academic_jobs(
             courses_taught=uf_courses,
             company_short_name=UF.abbreviation,
             short_job_title='GA',
+            hours_per_week=30,
         ),
         AcademicEmploymentModel(
             JobIDs.VCU_GA.value,
@@ -139,6 +144,7 @@ def get_academic_jobs(
             courses_taught=vcu_courses,
             company_short_name=VCU.abbreviation,
             short_job_title='GA',
+            hours_per_week=30,
         ),
     ]
 
@@ -169,11 +175,10 @@ def _replace_vcu_ga_description(description: Sequence[str]) -> Sequence[str]:
 
 CV_JOB_MODIFIERS: Dict[JobIDs, Callable[[Sequence[str]], Sequence[str]]] = {
     JobIDs.CNC_MP: _return_first,
-    JobIDs.FRB_INTERN: _return_first,
     JobIDs.VCU_GA: _replace_vcu_ga_description,
-    JobIDs.EVB_PORTFOLIO_ANALYST: _return_first_and_third,
 }
 
 CV_EXCLUDED_COMPANIES: List[JobIDs] = [
     JobIDs.PARLIAMENT_TUTOR,
+    JobIDs.CNC_MP,
 ]
\ No newline at end of file
