@@ -529,7 +529,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'ECS', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('6/1/2020', hours_per_week=0.25),
+        experience=SkillExperience('6/1/2020', hours_per_week=0.25, one_time_hours=20),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
     SkillModel(
